<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "redux_demo";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Theme Options', 'redux-framework-demo' ),
        'page_title'           => __( 'Theme Options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => 'industify_fn_option',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */
	$adminURL = '<a href="'.admin_url('options-permalink.php').'">'.esc_html__('Here', 'redux-framework-demo').'</a>';	 
	$permalink_description = __('After changing this, go to following link and click save. '.$adminURL.'', 'redux-framework-demo');

	$langURL = '<a target="_blank" href="https://wpml.org/">'.esc_html__('WPML Multilingual CMS', 'redux-framework-demo').'</a>';	 
	$lang_desc = __('Please, install and set up following plugin: '.$langURL.'', 'redux-framework-demo');
    // -> START Basic Fields
	Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'General', 'redux-framework-demo' ),
        'id'    => 'general',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-globe',
		'fields' 	=> array(
			array(
				'id'		=> 'site_rtl',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Right To Left Direction (RTL)', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'		=> 'pagination_text',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Pagination Text', 'redux-framework-demo'),
				"default" 	=> 'enable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'		=> 'industify_box_shadow',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('All Box Shadows', 'redux-framework-demo'),
				"default" 	=> 'enable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'		=> 'blog_single_title',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Page Title for Blog Single', 'redux-framework-demo'),
				'default'	=> esc_html__('Our Blog', 'redux-framework-demo'),
			),
			array(
				'id'		=> 'thumb_for_search',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Thumbnail for Search Page', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'		=> 'custom_lang_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Custom Links for Languagebox', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'          => 'custom_language_links',
				'type'        => 'slides',
				'title'       => esc_html__('Custom Language Links', 'redux-framework-demo'),
				'placeholder' => array(
					'title'         => esc_html__('Language', 'redux-framework-demo'),
					'url'     		=> 'https://www.example.com/',
				),
				'show'		=> array(
					'title'			=> true,
					'description'	=> false,
					'url'			=> true,
				),
				'required' => array( 'custom_lang_switch', '=', array('enable')),
			),
			
//			array(
//				'id' 		=> 'site_container_width',
//				'type' 		=> 'slider',
//				'title' 	=> esc_html__('Site Container Width (px)', 'redux-framework-demo'),
//				'subtitle' 	=> esc_html__('Default Value: 1170px', 'redux-framework-demo'),
//				"default" 	=> "1170",
//				"min" 		=> "1",
//				"step" 		=> "1",
//				"max" 		=> "2500",
//			),
		)
	));
	Redux::setSection( $opt_name, array(
			'title' => esc_html__( 'Main Colors', 'redux-framework-demo' ),
			'id'    => 'main_color',
			'icon'  => 'el el-brush ',
			'fields' 	=> array(
			array(
				'id'		=> 'heading_color',
				'type' 		=> 'color',
				'transparent' => false,
				'title' 	=> esc_html__('Heading Color', 'redux-framework-demo'),
				'default' 	=> '#14141c',
				'validate' 	=> 'color',
			),
			array(
				'id'		=> 'primary_color',
				'type' 		=> 'color',
				'transparent' => false,
				'title' 	=> esc_html__('Primary Color', 'redux-framework-demo'),
				'default' 	=> '#316397',
				'validate' 	=> 'color',
			),
			array(
				'id'		=> 'secondary_color',
				'type' 		=> 'color',
				'transparent' => false,
				'title' 	=> esc_html__('Secondary Color', 'redux-framework-demo'),
				'default' 	=> '#d24e1a',
				'validate' 	=> 'color',
			),
		)
	));
	Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Logo Options', 'redux-framework-demo' ),
        'id'    => 'logo',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-puzzle',
		'fields' 	=> array(
		
		
			array(
				'id'		=> 'desktop_logo_dark',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Desktop Dark Logo', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo.', 'redux-framework-demo'),
			),
		
			array(
				'id'		=> 'desktop_logo_light',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Desktop Light Logo', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo.', 'redux-framework-demo'),
			),
		
			array(
				'id'		=> 'mobile_logo',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Mobile Logo', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo.', 'redux-framework-demo'),
			),
		
			array(
				'id'		=> 'retina_logo_dark',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Retina Dark Logo', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo.', 'redux-framework-demo'),
			),
		
			array(
				'id'		=> 'retina_logo_light',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Retina Light Logo', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo.', 'redux-framework-demo'),
			),
		
		)
	));
Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Navigation', 'redux-framework-demo' ),
        'id'    => 'navigation',
        'icon'  => 'el el-th',
		'fields' 	=> array(
		
			array(
				'id'		=> 'nav_skin',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Navigation Skin', 'redux-framework-demo'),
				"default" 	=> 'light',
				'options' 	=> array(
								'dark'  		=> esc_html__('Dark', 'redux-framework-demo'),
								'light'  		=> esc_html__('Light', 'redux-framework-demo'),
								'transdark'  	=> esc_html__('Transdark', 'redux-framework-demo'),
								'translight'  	=> esc_html__('Translight', 'redux-framework-demo'),
								'nobgdark'  	=> esc_html__('None Background Dark', 'redux-framework-demo'),
								'nobglight'  	=> esc_html__('None Background Light', 'redux-framework-demo')),
			),
			array(
				'id'		=> 'special_nav_skin',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Navigation Skin For 404/Search/Archive Pages', 'redux-framework-demo'),
				"default" 	=> 'light',
				'options' 	=> array(
								'dark'  		=> esc_html__('Dark', 'redux-framework-demo'),
								'light'  		=> esc_html__('Light', 'redux-framework-demo'),
								'transdark'  	=> esc_html__('Transdark', 'redux-framework-demo'),
								'translight'  	=> esc_html__('Translight', 'redux-framework-demo'),
								'nobgdark'  	=> esc_html__('None Background Dark', 'redux-framework-demo'),
								'nobglight'  	=> esc_html__('None Background Light', 'redux-framework-demo')),
			),
			array(
				'id'		=> 'sticky_nav_switcher',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Sticky Navigation', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  			=> esc_html__('Enable', 'redux-framework-demo'),
								'disable' 			=> esc_html__('Disable', 'redux-framework-demo')),
		
			),
			array(
				'id'		=> 'mobile_menu_autocollapse',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Autocollapse mobile menu on click', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
			),
		)
    ));

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Info Bar', 'redux-framework-demo' ),
	'id'    => 'topbar',
	'icon'  => 'el el-info-circle',
	'fields' 	=> array(
			
			array(
			   	'id' 		=> 'toppanel_section_start',
			   	'type' 		=> 'section',
				'title' 	=> esc_html__('Top Bar Section', 'redux-framework-demo'),
			   	'indent' 	=> true,
			),
			
			array(
				'id'		=> 'toppanel_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
			),
		
			array(
				'id'		=> 'search_switcher',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Search Switcher', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
				'required' 		=> array(
					array('toppanel_switch','equals',array('enable')),
				),
			),
		
			array(
				'id'		=> 'woo_basket_switcher',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Woocommerce Basket Switcher', 'redux-framework-demo'),
				"default" 	=> 'enable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
				'required' 		=> array(
					array('toppanel_switch','equals',array('enable')),
				),
			),
		
			array(
				'id'			=> 'panel_multi_info',
				'type' 			=> 'multi_text',
				'title' 		=> __('Extra Information', 'redux-framework-demo'),
				'subtitle' 		=> __('Type your website information here', 'redux-framework-demo'),
				'default'		=> array(
					'<a href="tel:07787744741">(0778) 774 - 474 -1</a>',
					'<a href="mailto:demomail@industify.com">demomail@industify.com</a>',
				),
				'required' 		=> array(
					array('toppanel_switch','equals',array('enable')),
				),
			),
			array(
				'id'       => 'helpful_social_switcher',
				'type'     => 'switch', 
				'title'    => __('Social Switcher', 'redux-framework-demo'),
				'default'  => true,
				'required' 		=> array(
					array('toppanel_switch','equals',array('enable')),
				),
			),
			array(
				'id'       => 'social_position',
				'type'     => 'sortable',
				'title'    => __('List positions / switcher', 'redux-framework-demo'),
				'subtitle' => __('Define and reorder these however you want.', 'redux-framework-demo'),
				'mode'     => 'checkbox',
				'options'  => array(
					'facebook'     		=> __('Facebook', 'redux-framework-demo'),
					'twitter'     		=> __('Twitter', 'redux-framework-demo'),
					'pinterest'     	=> __('Pinterest', 'redux-framework-demo'),
					'linkedin'     		=> __('Linkedin', 'redux-framework-demo'),
					'behance'     		=> __('Behance', 'redux-framework-demo'),
					'vimeo'      		=> __('Vimeo', 'redux-framework-demo'),
					'google'      		=> __('Google', 'redux-framework-demo'),
					'youtube'      		=> __('Youtube', 'redux-framework-demo'),
					'instagram'      	=> __('Instagram', 'redux-framework-demo'),
					'github'      		=> __('Github', 'redux-framework-demo'),
					'flickr'      		=> __('Flickr', 'redux-framework-demo'),
					'dribbble'      	=> __('Dribbble', 'redux-framework-demo'),
					'dropbox'	      	=> __('Dropbox', 'redux-framework-demo'),
					'paypal'	      	=> __('Paypal', 'redux-framework-demo'),
					'picasa'	      	=> __('Picasa', 'redux-framework-demo'),
					'soundcloud'      	=> __('SoundCloud', 'redux-framework-demo'),
					'whatsapp'	      	=> __('Whatsapp', 'redux-framework-demo'),
					'skype'	      		=> __('Skype', 'redux-framework-demo'),
					'slack'	      		=> __('Slack', 'redux-framework-demo'),
					'wechat'	      	=> __('WeChat', 'redux-framework-demo'),
					'icq'	     	 	=> __('ICQ', 'redux-framework-demo'),
					'rocketchat'   	 	=> __('RocketChat', 'redux-framework-demo'),
					'rocketchat'   	 	=> __('RocketChat', 'redux-framework-demo'),						
					'telegram'	      	=> __('Telegram', 'redux-framework-demo'),
					'vk'		      	=> __('Vkontakte', 'redux-framework-demo'),
				),
				// For checkbox mode
				'default' => array(
				),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'facebook_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Facebook URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'twitter_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Twitter URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'pinterest_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Pinterest URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'linkedin_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Linkedin URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'behance_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Behance URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'vimeo_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Vimeo URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'google_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Google URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'youtube_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Youtube URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'instagram_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Instagram URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'github_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Github URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'flickr_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Flickr URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'dribbble_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Dribbble URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'dropbox_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Dropbox URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'paypal_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Paypal URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'picasa_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Picasa URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'soundcloud_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Soundcloud URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'whatsapp_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Whatsapp URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'skype_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Skype URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'slack_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Slack URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'wechat_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Wechat URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'icq_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('ICQ URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'rocketchat_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Rocketchat URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'telegram_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Telegram URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
			array(
				'id'		=> 'vk_helpful',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Vkontakte URL', 'redux-framework-demo'),
				'required' 		=> array(
					array('helpful_social_switcher','equals',true),
				),
			),
		
			array(
			   	'id' 		=> 'toppanel_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
			
			array(
				'id'		=> 'topbar_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Support Section', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
			),
			array(
				'id'		=> 'lang_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Multi Language', 'redux-framework-demo'),
				'subtitle' 	=> $lang_desc,
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
				'required' => array( 'topbar_switch', '=', array('enable')),
			),
			array(
			   	'id' 		=> 'tollfree_section_start',
			   	'type' 		=> 'section',
				'title' 	=> esc_html__('Toll Free', 'redux-framework-demo'),
			   	'indent' 	=> true,
				'required' 		=> array(
					array('topbar_switch','=','enable'),
				),
			),
		
			array(
				'id'		=> 'tollfree_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'),
								'disable'  		=> esc_html__('Disable', 'redux-framework-demo')),
				'required' => array( 'topbar_switch', '=', array('enable')),
			),
			array(
				'id'		=> 'topbar_img',
				'type' 		=> 'media',
				'url'       => true,
				'title' 	=> esc_html__('Upload Image', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('We suggest to use png logo. 42x42', 'redux-framework-demo'),
				'required' => array( 'tollfree_switch', '=', array('enable')),
			),
			array(
				'id'		=> 'toll_free_span',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Title', 'redux-framework-demo'),
				'default'	=> esc_html__('Toll Free:', 'redux-framework-demo'),
				'required' => array( 'tollfree_switch', '=', array('enable')),
			),
			array(
				'id'		=> 'toll_free_text',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Phone Number', 'redux-framework-demo'),
				'default'	=> '1-800-987-6543',
				'required' => array( 'tollfree_switch', '=', array('enable')),
			),
			array(
				'id'		=> 'toll_free_bg_color',
				'type' 		=> 'color',
				'transparent' => false,
				'title' 	=> esc_html__('Background Color', 'redux-framework-demo'),
				'default' 	=> '#316397',
				'validate' 	=> 'color',
				'required' => array( 'tollfree_switch', '=', array('enable')),
			),
			array(
				'id'		=> 'toll_free_text_color',
				'type' 		=> 'color',
				'transparent' => false,
				'title' 	=> esc_html__('Text Color', 'redux-framework-demo'),
				'default' 	=> '#fff',
				'validate' 	=> 'color',
				'required' => array( 'tollfree_switch', '=', array('enable')),
			),
		
			array(
			   	'id' 		=> 'tollfree_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
				

	)
));
	Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Typography', 'redux-framework-demo' ),
        'id'    => 'typography',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-font',
		'fields' 	=> array(
			array(
				'id'		=> 'body_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Body Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the body font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' => false,
				'text-align' => false,
				'default' 	=> array(
					'font-size' 	=> '14px',
					'font-family' 	=> 'Open Sans',
					'font-weight' 	=> '400',
				),
			),
			array(
				'id'		=> 'nav_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Desktop Navigation Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the navigation font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' 	=> false,
				'text-align' => false,
				'default' 	=> array(
					'font-size' 	=> '14px',
					'font-family' 	=> 'Rubik',
					'font-weight' 	=> '500',
				),
			),
			array(
				'id'		=> 'nav_mob_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Mobile Navigation Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the navigation font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' 	=> false,
				'text-align' => false,
				'default' 	=> array(
					'font-size' 	=> '18px',
					'font-family' 	=> 'Montserrat',
					'font-weight' 	=> '400',
				),
			),
		
			array(
				'id'		=> 'input_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Input Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the Input font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' 	=> false,
				'text-align' => false,
				'default' 	=> array(
					'font-size' 	=> '14px',
					'font-family' 	=> 'Open Sans',
					'font-weight' 	=> '400',
				),
			),
			array(
				'id'		=> 'blockquote_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Blockquote Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the blockquote font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' 	=> false,
				'text-align' => false,
				'default' 	=> array(
					'font-size' 	=> '16px',
					'font-family' 	=> 'Lora',
					'font-weight' 	=> '400',
				),
			),
			array(
				'id'		=> 'heading_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Heading Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the heading font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'color' 	=> false,
				'font-size' => false,
				'text-align' => false,
				'default' 	=> array(
					'font-family' 	=> 'Rubik',
					'font-weight' 	=> '400',
				),
			),
			array(
				'id'		=> 'extra_font',
				'type' 		=> 'typography',
				'title' 	=> esc_html__('Extra Font', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('Specify the extra font properties.', 'redux-framework-demo'),
				'google' 	=> true,
				'preview'	=> false,
				'line-height'=>false,
				'font-weight'=>false,
				'color' 	=> false,
				'font-size' => false,
				'text-align' => false,
				'default' 	=> array(
					'font-family' 	=> 'Montserrat',
				),
			),
		)
    ));
	
Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Project', 'redux-framework-demo' ),
        'id'    => 'project',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-folder-open',
		'fields' 	=> array(
			
			array(
				'id' 		=> 'project_perpage',
				'type' 		=> 'slider',
				'title' 	=> esc_html__('Project Posts Per Page', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('', 'redux-framework-demo'),
				"default" 	=> "6",
				"min" 		=> "1",
				"step" 		=> "1",
				"max" 		=> "30",
			),
			array(
				'id' 		=> 'project_slug',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Project Slug', 'frenify-core'),
				'subtitle' 	=> $permalink_description,
				'default' 	=> 'myproject',
			),
		
			array(
				'id' 		=> 'project_cat_slug',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Project Category Slug', 'frenify-core'),
				'subtitle' 	=> $permalink_description,
				'default' 	=> 'myproject-cat',
			),
			array(
				'id'		=> 'project_archive_title',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Title for Project Archive', 'redux-framework-demo'),
				'default'	=> esc_html__('Project Archive', 'redux-framework-demo'),
			),
			array(
				'id'		=> 'project_single_caption',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Project Single Caption', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			array(
				'id'		=> 'project_single_layout',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Single Layout', 'redux-framework-demo'),
				"default" 	=> 'justified',
				'options' 	=> array(
								'justified'  	=> esc_html__('Justified', 'redux-framework-demo'), 
								'sticky' 		=> esc_html__('Sticky', 'redux-framework-demo')),	
			),
			array(
				'id' 		=> 'ps_j_imgh',
				'type' 		=> 'slider',
				'title' 	=> esc_html__('Single Justified Images Height(px)', 'redux-framework-demo'),
				"default" 	=> "300",
				"min" 		=> "100",
				"step" 		=> "10",
				"max" 		=> "700",
				'required' => array( 'project_single_layout', '=', array('justified')),
			),
		
			array(
				'id'		=> 'ps_j_gutter',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Single Justified Images Gutter', 'redux-framework-demo'),
				"default" 	=> '10',
				'options' 	=> array(
								'0'  		=> esc_html__('No Gutter', 'redux-framework-demo'),
								'1'  		=> esc_html__('1px', 'redux-framework-demo'),
								'5'  		=> esc_html__('5px', 'redux-framework-demo'),
								'10'  		=> esc_html__('10px', 'redux-framework-demo'),
								'20'  		=> esc_html__('20px', 'redux-framework-demo'),
								'30'  		=> esc_html__('30px', 'redux-framework-demo'),
								'40'  		=> esc_html__('40px', 'redux-framework-demo'),
								'50'  		=> esc_html__('50px', 'redux-framework-demo'),
								'60'  		=> esc_html__('60px', 'redux-framework-demo'),
								'70'  		=> esc_html__('70px', 'redux-framework-demo'),
								'80'  		=> esc_html__('80px', 'redux-framework-demo')),
				'required' => array( 'project_single_layout', '=', array('justified')),
			),
			array(
				'id'		=> 'project_video_text',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Video Text', 'redux-framework-demo'),
				'default'	=> esc_html__('See Our Work Process', 'redux-framework-demo'),
			),
	)
));
Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Service', 'redux-framework-demo' ),
        'id'    => 'service',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-briefcase',
		'fields' 	=> array(
			
			array(
				'id' 		=> 'service_perpage',
				'type' 		=> 'slider',
				'title' 	=> esc_html__('Service Posts Per Page', 'redux-framework-demo'),
				'subtitle' 	=> esc_html__('', 'redux-framework-demo'),
				"default" 	=> "6",
				"min" 		=> "1",
				"step" 		=> "1",
				"max" 		=> "30",
			),
			array(
				'id' 		=> 'service_slug',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Service Slug', 'frenify-core'),
				'subtitle' 	=> $permalink_description,
				'default' 	=> 'myservice',
			),
		
			array(
				'id' 		=> 'service_cat_slug',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Service Category Slug', 'frenify-core'),
				'subtitle' 	=> $permalink_description,
				'default' 	=> 'myservice-cat',
			),
			array(
				'id'		=> 'service_layout',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Service Layout', 'redux-framework-demo'),
				"default" 	=> 'list',
				'options' 	=> array(
								'list'  		=> esc_html__('List', 'redux-framework-demo'), 
								'masonry' 		=> esc_html__('masonry', 'redux-framework-demo')),	
			),
			array(
				'id'		=> 'service_archive_title',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Title for Service Archive', 'redux-framework-demo'),
				'default'	=> esc_html__('Service Archive', 'redux-framework-demo'),
			),
			array(
				'id'		=> 'service_bread_title',
				'type' 		=> 'text',
				'title' 	=> esc_html__('Service Posts in Breadcrumbs', 'redux-framework-demo'),
				'default'	=> esc_html__('Service Posts', 'redux-framework-demo'),
			),
	)
));
Redux::setSection( $opt_name, array(
        'title' => __( 'Share Options', 'redux-framework-demo' ),
        'id'    => 'sharebox',
        'desc'  => __( '', 'redux-framework-demo' ),
        'icon'  => 'el el-share-alt',
		'fields' 	=> array(  
			array(
				'id' 		=> 'share_facebook',
				'type' 		=> 'button_set',
				'title' 	=> __('Facebook', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
				'default' 	=> 'enable'
			),
			array(
				'id' 		=> 'share_twitter',
				'type' 		=> 'button_set',
				'title' 	=> __('Twitter', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
				'default' 	=> 'enable'
			),
			array(
				'id' 		=> 'share_google',
				'type' 		=> 'button_set',
				'title' 	=> __('Google Plus', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
				'default' 	=> 'enable'
			),
			array(
				'id' 		=> 'share_pinterest',
				'type' 		=> 'button_set',
				'title' 	=> __('Pinterest', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
				'default' 	=> 'enable'
			),
			array(
				'id' 		=> 'share_linkedin',
				'type' 		=> 'button_set',
				'title' 	=> __('Linkedin', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
				'default' 	=> 'disable'
			),
			array(
				'id' 		=> 'share_email',
				'type' 		=> 'button_set',
				'title' 	=> __('Email', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
				'default' 	=> 'disable'
			),
			array(
				'id' 		=> 'share_vk',
				'type' 		=> 'button_set',
				'title' 	=> __('Vkontakte', 'redux-framework-demo'),
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
				'default' 	=> 'enable'
			),
		)
    ));
   Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Footer', 'redux-framework-demo' ),
        'id'    => 'footer',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-road',
		'fields' 	=> array(
			array(
				'id'		=> 'footer_switch',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Enable/Disable Footer', 'redux-framework-demo'),
				"default" 	=> 'enable',
				'options' 	=> array(
								'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
								'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),			
			),
			
			
			array(
			   	'id' 			=> 'footer_subscribe_area_section_start',
			   	'type' 			=> 'section',
				'title' 		=> esc_html__('Subscribe Section', 'redux-framework-demo'),
			   	'indent' 		=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				array(
					'id'		=> 'footer_subscribe_area',
					'type' 		=> 'button_set',
					'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
					"default" 	=> 'disable',
					'options' 	=> array(
									'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
									'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),	
				),
				
				array(
					'id' 		=> 'footer_subscribe_text',
					'type' 		=> 'textarea',
					'title' 	=> esc_html__('Text', 'redux-framework-demo'),
					'default' 	=> esc_html__('Newsletter — get updates with latest topics', 'redux-framework-demo'),
				),
			array(
			   	'id' 		=> 'footer_subscribe_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
	   		
			array(
			   	'id' 			=> 'footer_triple_area_section_start',
			   	'type' 			=> 'section',
				'title' 		=> esc_html__('Three Widgets Section', 'redux-framework-demo'),
			   	'indent' 		=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				
				array(
					'id'		=> 'footer_widget_switch',
					'type' 		=> 'button_set',
					'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
					"default" 	=> 'disable',
					'options' 	=> array(
									'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
									'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),	
				),
			
			array(
			   	'id' 		=> 'footer_triple_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
	   		
			array(
			   	'id' 			=> 'footer_bottom_area_section_start',
			   	'type' 			=> 'section',
				'title' 		=> esc_html__('Bottom Widget Section', 'redux-framework-demo'),
			   	'indent' 		=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				array(
					'id'		=> 'footer_bottom_widget_switch',
					'type' 		=> 'button_set',
					'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
					"default" 	=> 'disable',
					'options' 	=> array(
									'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
									'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),		
				),
			
			array(
			   	'id' 		=> 'footer_bottom_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
			
			
			
			array(
			   	'id' 		=> 'footer_copyright_section_start',
			   	'type' 		=> 'section',
				'title' 	=> esc_html__('Copyright Section', 'redux-framework-demo'),
			   	'indent' 	=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				array(
					'id'		=> 'footer_copyright_switch',
					'type' 		=> 'button_set',
					'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
					"default" 	=> 'enable',
					'options' 	=> array(
									'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
									'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),

					'required' => array( 'footer_switch', '=', array('enable') ),			
				),
				array(
					'id' 		=> 'footer_copyright',
					'type' 		=> 'textarea',
					'title' 	=> esc_html__('Text', 'redux-framework-demo'),
					'default' 	=> wp_kses_post('Copyright &copy; 2021, Industify LCC. Designed by <a href="https://frenify.com/" target="_blank">frenify.com</a> Industify WordPress Theme. Built with love in London. All rights reserved.'),
				),
			array(
			   	'id' 		=> 'footer_copyright_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
	   		
			
			
			array(
			   	'id' 			=> 'footer_totop_section_start',
			   	'type' 			=> 'section',
				'title' 		=> esc_html__('Totop Button', 'redux-framework-demo'),
			   	'indent' 		=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				array(
					'id'		=> 'totop_switch',
					'type' 		=> 'button_set',
					'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
					"default" 	=> 'enable',
					'options' 	=> array(
									'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
									'disable' 		=> esc_html__('Disable', 'redux-framework-demo')
					),		
				),

				array(
					'id' 		=> 'totop_text',
					'type' 		=> 'text',
					'title' 	=> esc_html__('Text', 'redux-framework-demo'),
					'default' 	=> esc_html__('To Top', 'redux-framework-demo'),
				),
			
			array(
			   	'id' 		=> 'footer_totop_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
			
			array(
			   	'id' 			=> 'footer_design_section_start',
			   	'type' 			=> 'section',
				'title' 		=> esc_html__('Footer Design', 'redux-framework-demo'),
			   	'indent' 		=> true,
				'required' 		=> array(
					array('footer_switch','=','enable'),
				),
			),
				
				array(
					'id'		=> 'footer_bg',
					'type' 		=> 'media',
					'url'       => true,
					'title' 	=> esc_html__('Background Image', 'redux-framework-demo'),
				),

				array(
					'id'		=> 'footer_bg_1',
					'type' 		=> 'color',
					'transparent' => false,
					'title' 	=> esc_html__('#1 Background Color', 'redux-framework-demo'),
					'default' 	=> '#081225',
					'validate' 	=> 'color',
				),
				array(
					'id'		=> 'footer_bg_2',
					'type' 		=> 'color',
					'transparent' => false,
					'title' 	=> esc_html__('#2 Background Color', 'redux-framework-demo'),
					'default' 	=> '#081225',
					'validate' 	=> 'color',
				),
				array(
					'id'		=> 'footer_special_color',
					'type' 		=> 'color',
					'transparent' => false,
					'title' 	=> esc_html__('Special Regular Color', 'redux-framework-demo'),
					'default' 	=> '#316397',
					'validate' 	=> 'color',
				),
				array(
					'id'		=> 'footer_special_h_color',
					'type' 		=> 'color',
					'transparent' => false,
					'title' 	=> esc_html__('Special Hover Color', 'redux-framework-demo'),
					'default' 	=> '#d24e1a',
					'validate' 	=> 'color',
				),
			
			array(
			   	'id' 		=> 'footer_design_area_section_end',
			   	'type' 		=> 'section',
			   	'indent' 	=> false,
			),
		),
	));
	Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Woo Options', 'redux-framework-demo' ),
        'id'    => 'fn_woo_page',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-shopping-cart',
		'fields' 	=> array(
			
			array(
				'id'		=> 'woo_product_img_grid',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Products Grid Type', 'redux-framework-demo'),
				"default" 	=> 'square',
				'options' 	=> array(
								'square'  			=> esc_html__('Square', 'redux-framework-demo'),
								'portrait'  		=> esc_html__('Portrait', 'redux-framework-demo'),
								'landscape' 		=> esc_html__('Landscape', 'redux-framework-demo')),
			),
		
			array(
				'id' 		=> 'woo_per_page',
				'type' 		=> 'slider',
				'title' 	=> esc_html__('Products Per Page', 'redux-framework-demo'),
				"default" 	=> "12",
				"min" 		=> "1",
				"step" 		=> "1",
				"max" 		=> "100",
			),
			array(
				'id'		=> 'woo_category_product_sidebar',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Product Category Sidebar', 'redux-framework-demo'),
				"default" 	=> 'disable',
				'options' 	=> array(
								'enable'  			=> esc_html__('Enable', 'redux-framework-demo'),
								'disable' 			=> esc_html__('Disable', 'redux-framework-demo')),
			),
			
		)
    ));
	Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Custom CSS', 'redux-framework-demo' ),
        'id'    => 'css',
        'desc'  => esc_html__( '', 'redux-framework-demo' ),
        'icon'  => 'el el-edit',
		'fields' 	=> array(
			array(
				'id' 		=> 'custom_css',
				'type' 		=> 'textarea',
				'title' 	=> esc_html__('Custom CSS', 'redux-framework-demo'),
			),				
		)
    )); 

    /*
     * <--- END SECTIONS
     */
