<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Contact extends Widget_Base {

	public function get_name() {
		return 'frel-contact';
	}

	public function get_title() {
		return __( 'Contact Shortcode', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-image-box frenifyicon-elementor frenifyicon-industify';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'industify'
        ];
    }

	protected function _register_controls() {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'shortcode',
			  [
				 'label'       => __( 'Shortcode', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXTAREA,
				 'placeholder' => __( 'Insery your shortcode here', 'frenify-core' ),
			  ]
		);
		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'coloring',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'placeholder_color',
			[
				'label' => __( 'Placeholder Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="text"]::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="text"]::-moz-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="text"]::-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="text"]:-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]::-moz-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]::-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]:-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea::-moz-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea::-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea:-ms-input-placeholder' => 'color: {{VALUE}} !important;',
				],
				'default' => '#777',
			]
		);
		
		
		$this->add_control(
			'input_color',
			[
				'label' => __( 'Input Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="text"]' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea' => 'color: {{VALUE}} !important;',
				],
				'default' => '#111',
			]
		);
		
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="text"]' => 'background-color: {{VALUE}} !important;',
					'{{WRAPPER}} input[type="email"]' => 'background-color: {{VALUE}} !important;',
					'{{WRAPPER}} textarea' => 'background-color: {{VALUE}} !important;',
				],
				'default' => '#eee',
			]
		);
		
		$this->add_control(
			'button_color',
			[
				'label' => __( 'Button Regular Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="submit"]' => 'color: {{VALUE}} !important;',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'btn_h_color',
			[
				'label' => __( 'Button Hover Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="submit"]:hover' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'button_bg_color',
			[
				'label' => __( 'Button Regular Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="submit"]' => 'background-color: {{VALUE}} !important;',
				],
				'default' => '#16161b',
			]
		);
		
		$this->add_control(
			'btn_bg_h_color',
			[
				'label' => __( 'Button Hover Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} input[type="submit"]:hover' => 'background-color: {{VALUE}} !important;',
				],
				'default' => '#1B8ED7',
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'frenify-core' ),
				'selector' => '{{WRAPPER}} input[type=text],{{WRAPPER}} input[type=email],{{WRAPPER}} textarea',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'typography',
			[
				'label' => __( 'Typography', 'frenify-core' ),
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'submit_typography',
				'label' => __( 'Submit Typography', 'frenify-core' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} input[type="submit"]',
				'fields_options' => [
					'font_weight' => [
						'default' => '400',
					],
					'font_family' => [
						'default' => 'Open Sans',
					],
					'font_size'   => [
						'default' => [
										'unit' => 'px',
										'size' => '16'
									]
					],
					'line_height' => [
						'default' => [
										'unit' => 'em',
										'size' => '1',
									]
					],
					'letter_spacing' => [
						'default' => [
										'unit' => 'px',
										'size' => '0',
									]
					],
				],
			]
		);
		
		$this->end_controls_section();
		
	}
	
	
	
	

	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 		= $this->get_settings();
		$shortcode		= $settings['shortcode'];
		
		$shortcode		= do_shortcode( shortcode_unautop( $shortcode ) );
		
		
		
		
		
	
		$html		= Frel_Helper::frel_open_wrap();
		
		$shortcode 	= '<div>'.$shortcode.'</div>';
		
		$html .= '<div class="fn_cs_contact_shortcode">'.$shortcode.'</div>';
		
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
