<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Project_Elegant_List extends Widget_Base {

	public function get_name() {
		return 'frel-project-elegant-list';
	}

	public function get_title() {
		return __( 'Project Elegant List', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-post frenifyicon-elementor frenifyicon-industify';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'industify'
        ];
    }

	protected function _register_controls() {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Projects List', 'frenify-core' ),
			]
		);
		
		
		$this->add_control(
            'layout',
            [
                'label' => esc_html__( 'Layout', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alpha' 	=> esc_html__( 'Alpha', 'frenify-core' ),
                    'beta' 		=> esc_html__( 'Beta', 'frenify-core' )
                ],
                'default' => 'beta',
            ]
        );
		
		
		$this->add_control(
			'post_number',
			[
				'label' => __( 'Post Number', 'frenify-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 6,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 999,
						'step' => 1,
					]
				],
			]
		);
		
		
		$this->add_control(
			'post_include_categories',
			[
				 'label'	 	=> __( 'Include Categories', 'frenify-core' ),
				 'description'	=> __( 'Select a category to include or leave blank for all.', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllCategories('project_category')
			]
		);
		$this->add_control(
			'post_exclude_categories',
			[
				 'label'	 	=> __( 'Exclude Categories', 'frenify-core' ),
				 'description'	=> __( 'Select a category to exclude', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllCategories('project_category')
			]
		);
		
		$this->add_control(
            'post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0'
            ]
        );
		
		$this->add_control(
            'post_order',
            [
                'label' => esc_html__( 'Post Order', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'frenify-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'frenify-core' )
                ],
                'default' => 'desc',

            ]
        );
		
		$this->add_control(
            'post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'frenify-core' ),
                    'ID' 				=> esc_html__( 'By ID', 'frenify-core' ),
                    'author' 			=> esc_html__( 'By Author', 'frenify-core' ),
                    'title' 			=> esc_html__( 'By Title', 'frenify-core' ),
                    'name' 				=> esc_html__( 'By Name', 'frenify-core' ),
                    'rand' 				=> esc_html__( 'Random', 'frenify-core' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'frenify-core' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'frenify-core' ),
                ],
                'default' => 'select',

            ]
        );
		
		
		$this->end_controls_section();


		$this->start_controls_section(
			'section3',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		$this->add_control(
			'p_cat_color',
			[
				'label' => __( 'Category Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .title_holder p a:after' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .title_holder p' => 'color: {{VALUE}};',
				],
				'default' => '#777',
			]
		);
		$this->add_control(
			'p_title_color',
			[
				'label' => __( 'Title Regular Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#1e1e1e',
			]
		);
		$this->add_control(
			'p_title_h_color',
			[
				'label' => __( 'Title Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#1b8ed7',
			]
		);
		
		$this->end_controls_section();
		
		
		$this->start_controls_section(
			'container_section',
			[
				'label' => __( 'Container', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'fn_container',
			[
				'label' 	=> __( 'Page Width', 'frenify-core' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'container',
				'options' 	=> [
					''  			=> __( 'Full', 'frenify-core' ),
					'container'  	=> __( 'Contained', 'frenify-core' ),
				],
			]
		);
		
		$this->add_control(
			'fn_container_custom',
			[
				'label' 		=> __( 'Custom Width', 'frenify-core' ),
				'description' 	=> __( 'Default: 1250px', 'frenify-core' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'enabled',
				'options' 		=> [
					'disabled'  	=> __( 'Disabled', 'frenify-core' ),
					'enabled'  		=> __( 'Enabled', 'frenify-core' ),
				],
				'condition' => [
					'fn_container' => 'container',
				]
			]
		);
		
		$this->add_control(
			'fn_container_width',
			[
				'label' 		=> __( 'Max Width', 'frenify-core' ),
				'description' 	=> __( 'Please, mind that container has padding from left and right by 40px.', 'frenify-core' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 		=> [
					'px' => [
						'min' => 0,
						'max' => 3000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1480,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_container.enabled' => 'max-width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'fn_container_custom' => 'enabled',
				]
			]
		);
		
		$this->end_controls_section();
	}




	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 					= $this->get_settings();
		$layout 					= $settings['layout'];
		$post_number 				= $settings['post_number']['size'];
		$post_order 				= $settings['post_order'];
		$post_orderby 				= $settings['post_orderby'];
		$post_offset 				= $settings['post_offset'];
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}
		// portfolio posts options
		$include_categories 		= '';
		if(!empty($settings['post_include_categories'])){
			$include_categories 	= $settings['post_include_categories'];
		}
		$exclude_categories 		= '';
		if(!empty($settings['post_exclude_categories'])){
			$exclude_categories	 	= $settings['post_exclude_categories'];
		}
		$query_args = array(
			'post_type' 			=> 'industify-project',
			'posts_per_page' 		=> $post_number,
			'post_status' 			=> 'publish',
			'order' 				=> $post_order,
			'orderby' 				=> $post_orderby,
			'offset' 				=> $post_offset,
		);
		if ( ! empty ( $exclude_categories ) ) {

			// Exclude the correct cats from tax_query
			$query_args['tax_query'] = array(
				array(
					'taxonomy'	=> 'project_category', 
					'field'	 	=> 'slug',
					'terms'		=> $exclude_categories,
					'operator'	=> 'NOT IN'
				)
			);

			// Include the correct cats in tax_query
			if ( ! empty ( $include_categories ) ) {
				$query_args['tax_query']['relation'] = 'AND';
				$query_args['tax_query'][] = array(
					'taxonomy'	=> 'project_category',
					'field'		=> 'slug',
					'terms'		=> $include_categories,
					'operator'	=> 'IN'
				);
			}		

		} else {
			// Include the cats from $cat_slugs in tax_query
			if ( ! empty ( $include_categories ) ) {
				$query_args['tax_query'] = array(
					array(
						'taxonomy' 	=> 'project_category',
						'field' 	=> 'slug',
						'terms' 	=> $include_categories,
						'operator'	=> 'IN'
					)
				);
			}
		}
		
		
		// ****************************** Container ***********************************
		$fnContainer	= $settings['fn_container'];								//*
		$fnContCustom	= $settings['fn_container_custom'];							//*
		if($fnContainer == 'container'){											//*
			$fnC_Start	= '<div class="container fn_container '.$fnContCustom.'">';	//*
			$fnC_End	= '</div>';													//*
		}else{																		//*
			$fnC_Start 	= $fnC_End = '';											//*
		}																			//*
		// ****************************************************************************
		
		$industify_post_loop 		= new \WP_Query($query_args);
		
		
		$list = '<div class="fn_cs_project_elegant_list" data-layout="'.$layout.'">';
		$callBackBig 	= '<img src="'.FREL_PLUGIN_URL.'assets/img/thumb-910-740.jpg" alt="" />';
		$callBackSmall 	= '<img src="'.FREL_PLUGIN_URL.'assets/img/thumb-420-300.jpg" alt="" />';
		foreach ( $industify_post_loop->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 			= $fn_post->ID;
			$post_permalink 	= get_permalink($post_id);
			$post_image 		= get_the_post_thumbnail_url( $post_id, 'full' );
			$post_title			= $fn_post->post_title;
			$post_cats			= Frel_Helper::post_term_list($post_id, 'project_category', false, 2, ', ');
			
			$title_holder 		= '<div class="title_holder"><p>'.$post_cats.'</p><h3><a href="'.$post_permalink.'">'.$post_title.'</a></h3></div>';
			$modul6 			= $key%6;
			$modul12 			= $key%12;
			if($modul12 == 6){
				$extraClass		= 'fn_reversed';
			}else{
				$extraClass		= '';
			}
			if($modul6 == 0){
				$img_holder = '<div class="img_holder">'.$callBackBig.'<div class="abs_img" data-bg-img="'.$post_image.'"><a href="'.$post_permalink.'"></a></div></div>';
				
				$list .= '<div class="items first_line '.$extraClass.'">'; // First Line >>>>
				$list .= '<div class="left_part">'; // Left Part >>>>
				$list .= '<div class="item_wrapper"><div class="item">'.$img_holder.$title_holder.'</div></div>';
				$list .= '</div>'; // Left Part <<<<
			}else if($modul6 == 1){
				$img_holder = '<div class="img_holder">'.$callBackSmall.'<div class="abs_img" data-bg-img="'.$post_image.'"><a href="'.$post_permalink.'"></a></div></div>';
				
				$list .= '<div class="right_part">'; // Right Part >>>>
				$list .= '<div class="item_wrapper"><div class="item">'.$img_holder.$title_holder.'</div></div>';
			}else if($modul6 == 2){
				$img_holder = '<div class="img_holder">'.$callBackSmall.'<div class="abs_img" data-bg-img="'.$post_image.'"><a href="'.$post_permalink.'"></a></div></div>';
				
				$list .= '<div class="item_wrapper"><div class="item">'.$img_holder.$title_holder.'</div></div>';
				$list .= '</div>'; // Right Part <<<<
				$list .= '</div>'; // First Line <<<<
			}else{
				$img_holder = '<div class="img_holder">'.$callBackSmall.'<div class="abs_img" data-bg-img="'.$post_image.'"><a href="'.$post_permalink.'"></a></div></div>';
				if($modul6 == 3){
					$list .= '<div class="items second_line">'; // Second Line >>>>
				}
				$list .= '<div class="item_wrapper"><div class="item">'.$img_holder.$title_holder.'</div></div>';
				if($modul6 == 5){
					$list .= '</div>'; // Second Line <<<<
				}
			}
			wp_reset_postdata();
		}
		
		if($modul6 == 0){
			$list .= '</div>'; // First Line <<<<
		}else if($modul6 == 1){
			$list .= '</div>'; // Right Part <<<<
			$list .= '</div>'; // First Line <<<<
		}else if($modul6 == 3 || $modul6 == 4){
			$list .= '</div>'; // Second Line <<<<
		}
		$list .= '</div>';
		
		
		$html = Frel_Helper::frel_open_wrap();
		$html .= $fnC_Start;
		$html .= $list;
		$html .= $fnC_End;
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
