<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Service_Query extends Widget_Base {

	public function get_name() {
		return 'frel-service-query';
	}

	public function get_title() {
		return __( 'Service Query', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-post frenifyicon-elementor frenifyicon-industify';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'industify'
        ];
    }

	protected function _register_controls() {
		

		$this->start_controls_section(
			'section2',
			[
				'label' => __( 'Top Bar', 'frenify-core' ),
			]
		);
		
		
		
		$this->add_control(
			'title',
			  [
				 'label'       => __( 'Title', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXTAREA,
				 'placeholder' => __( 'Type your title here', 'frenify-core' ),
				 'default' 	   => __( 'Our Industries', 'frenify-core' ),
			  ]
		);
		$this->add_control(
			'desc',
			  [
				 'label'       => __( 'Description', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXTAREA,
				 'placeholder' => __( 'Type your description link here', 'frenify-core' ),
				 'default' 	   => __( 'The automotive industry is the technological trendsetter among manufacturing industries.', 'frenify-core' ),
			  ]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Services', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'column_count',
			[
				'label' => __( 'Column Count', 'frenify-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 4,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 5,
						'step' => 1,
					]
				],
			]
		);
		
		$this->add_control(
			'post_number',
			[
				'label' => __( 'Post Number', 'frenify-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 6,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 20,
						'step' => 1,
					]
				],
			]
		);
		
		$this->add_control(
            'post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0'
            ]
        );
		
		$this->add_control(
            'post_order',
            [
                'label' => esc_html__( 'Post Order', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'frenify-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'frenify-core' )
                ],
                'default' => 'desc',

            ]
        );
		
		$this->add_control(
            'post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'frenify-core' ),
                    'ID' 				=> esc_html__( 'By ID', 'frenify-core' ),
                    'author' 			=> esc_html__( 'By Author', 'frenify-core' ),
                    'title' 			=> esc_html__( 'By Title', 'frenify-core' ),
                    'name' 				=> esc_html__( 'By Name', 'frenify-core' ),
                    'rand' 				=> esc_html__( 'Random', 'frenify-core' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'frenify-core' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'frenify-core' ),
                ],
                'default' => 'select',

            ]
        );
		
		
		$this->add_control(
			'view_more',
			  [
				 'label'       => __( 'View More Text', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXT,
				 'placeholder' => __( 'Type view more text here', 'frenify-core' ),
				 'default' 	   => __( 'View More', 'frenify-core' ),
				 'label_block' => true,
			  ]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'mobile_section',
			[
				'label' => __( 'Mobile Version', 'frenify-core' ),
			]
		);
		$this->add_control(
            'mobile_destroy',
            [
                'label' => esc_html__( 'Mobile Layout', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enable' 	=> esc_html__( 'Enable', 'frenify-core' ),
                    'disable' 	=> esc_html__( 'Disable', 'frenify-core' )
                ],
                'default' => 'disable',

            ]
        );
		$this->add_control(
			'mobile_post_number',
			[
				'label' => __( 'Mobile Post Number', 'frenify-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 2,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 20,
						'step' => 1,
					]
				],
			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section3',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		$this->add_control(
			'heading_topbar',
			[
				'label' 	=> __( 'Top Bar', 'frenify-core' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			't_bg_color',
			[
				'label' => __( 'Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .top_bar' => 'background-color: {{VALUE}};',
				],
				'default' => '#111724',
			]
		);
		$this->add_control(
			't_title_color',
			[
				'label' => __( 'Title Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .t_inner h3' => 'color: {{VALUE}};',
				],
				'default' => '#eee',
			]
		);
		$this->add_control(
			't_desc_color',
			[
				'label' => __( 'Description Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .t_inner span' => 'color: {{VALUE}};',
				],
				'default' => '#bbb',
			]
		);
		$this->add_control(
			'heading_control',
			[
				'label' 	=> __( 'Navigation Control', 'frenify-core' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'control_bg_color',
			[
				'label' => __( 'Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .owl_control div' => 'background-color: {{VALUE}};',
				],
				'default' => '#d24e1a',
			]
		);
		$this->add_control(
			'control_arr_color',
			[
				'label' => __( 'Arrow Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .owl_control .fn_prev:after' => 'border-right-color: {{VALUE}};',
					'{{WRAPPER}} .owl_control .fn_next:after' => 'border-left-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'heading_service',
			[
				'label' 	=> __( 'Service Section', 'frenify-core' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'service_hover_bg_color',
			[
				'label' => __( 'Hover Overlay Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .service_part .item .img_holder:after' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,0.6)',
			]
		);
		$this->add_control(
			'service_title_color',
			[
				'label' => __( 'Title Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .service_part .item .title h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#eee',
			]
		);
		$this->add_control(
			'service_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .service_part .item .title h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'service_link_color',
			[
				'label' => __( 'View More Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .service_part .item .view_more a' => 'color: {{VALUE}};border-color: {{VALUE}};',
				],
				'default' => '#eee',
			]
		);
		$this->add_control(
			'service_link_hover_color',
			[
				'label' => __( 'View More Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .service_part .item .view_more a:hover' => 'color: {{VALUE}};border-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->end_controls_section();
		
	}




	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 	= $this->get_settings();
		
		
		$view_more 					= $settings['view_more'];
		$mobile_layout				= $settings['mobile_destroy'];
		$title 						= $settings['title'];
		$desc 						= $settings['desc'];
		$post_number 				= $settings['post_number']['size'];
		$mobile_post_number			= $settings['mobile_post_number']['size'];
		$column_count 				= $settings['column_count']['size'];
		$post_order 				= $settings['post_order'];
		$post_orderby 				= $settings['post_orderby'];
		$post_offset 				= $settings['post_offset'];
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}
		$html = do_shortcode('[frenify_service_query view_more="'.$view_more.'" mobile_layout="'.$mobile_layout.'" title="'.$title.'" desc="'.$desc.'" post_number="'.$post_number.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" post_offset="'.$post_offset.'" column_count="'.$column_count.'" mobile_post_number="'.$mobile_post_number.'"]');
		echo $html;
	}

}
