<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Triple_Blog_Modern extends Widget_Base {

	public function get_name() {
		return 'frel-triple-blog-modern';
	}

	public function get_title() {
		return __( 'Triple Blog Modern', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-posts-grid frenifyicon-elementor frenifyicon-industify';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'industify'
        ];
    }

	protected function _register_controls() {
		
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', 'frenify-core' ),
			]
		);
		
		$this->add_control(
            'layout',
            [
                'label' => esc_html__( 'Layout', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alpha' 	=> esc_html__( 'Alpha', 'frenify-core' ),
                    'beta' 		=> esc_html__( 'Beta', 'frenify-core' )
                ],
                'default' => 'alpha',
            ]
        );
		
		$this->add_control(
            'post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0'
            ]
        );
		
		$this->add_control(
            'post_order',
            [
                'label' => esc_html__( 'Post Order', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'frenify-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'frenify-core' )
                ],
                'default' => 'desc',
            ]
        );
		
		$this->add_control(
            'post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'frenify-core' ),
                    'ID' 				=> esc_html__( 'By ID', 'frenify-core' ),
                    'author' 			=> esc_html__( 'By Author', 'frenify-core' ),
                    'title' 			=> esc_html__( 'By Title', 'frenify-core' ),
                    'name' 				=> esc_html__( 'By Name', 'frenify-core' ),
                    'rand' 				=> esc_html__( 'Random', 'frenify-core' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'frenify-core' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'frenify-core' ),
                ],
                'default' => 'select',

            ]
        );
		
		$this->add_control(
			'read_more',
			  [
				 'label'       => __( 'Read More Text', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXT,
				 'placeholder' => __( 'Read More text here', 'frenify-core' ),
				 'default'	   => __( 'Read More', 'frenify-core' ),
				 'condition' => [
					'layout' => 'alpha',
				 ]
			  ]
		);
		$this->add_control(
            'time_format',
            [
                'label' => esc_html__( 'Date Format', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'month_d_y' 			=> esc_html__( 'Jule 3, 2019', 'frenify-core' ),
                    'm_d_y' 				=> esc_html__( '07/03/2019', 'frenify-core' ),
                    'y_m_d' 				=> esc_html__( '2019/07/03', 'frenify-core' ),
                    'time'	 				=> esc_html__( '18:30', 'frenify-core' ),
                    'time_pm' 				=> esc_html__( '06:30pm', 'frenify-core' ),
                ],
                'default' => 'month_d_y',
				 'condition' => [
					'layout' => 'beta',
				 ]
            ]
        );
		
		$this->add_control(
            'read_more_type',
            [
                'label' => esc_html__( 'Read More Type', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'bg' 	=> esc_html__( 'With Background', 'frenify-core' ),
                    'arr' 	=> esc_html__( 'With Arrow', 'frenify-core' )
                ],
                'default' => 'bg',
				 'condition' => [
					'layout' => 'alpha',
				 ]
            ]
        );
		
		$this->add_control(
            'gutter',
            [
                'label' => esc_html__( 'Gutter', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '40',
				'selectors' => [
					'{{WRAPPER}} .fn_cs_triple_blog_modern li' => 'padding-left: {{VALUE}}px;margin-bottom: {{VALUE}}px;',
					'{{WRAPPER}} .fn_cs_triple_blog_modern ul' => 'margin-left: -{{VALUE}}px;',
				],
            ]
        );
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section2',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		$this->add_control(
			'time_bg_color',
			[
				'label' => __( 'Time Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .time span:after' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .time span:before' => 'border-top-color: {{VALUE}};',
				],
				'default' => '#d24e1a',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'time_text_color',
			[
				'label' => __( 'Time Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .time h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .time h5' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'time_line_color',
			[
				'label' => __( 'Time Line Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .time h3:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#ffc600',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Subtitle Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder p.t_header' => 'color: {{VALUE}};',
				],
				'default' => '#666',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'subtitle_link_color',
			[
				'label' => __( 'Subtitle Link Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_header a' => 'color: {{VALUE}};border-bottom-color: {{VALUE}}',
				],
				'default' => '#45a2df',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#041230',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'title_h_color',
			[
				'label' => __( 'Title Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#45a2df',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'read_more_color',
			[
				'label' => __( 'Read More Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_footer a.bg' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'read_more_bg_color',
			[
				'label' => __( 'Read More Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_footer a.bg' => 'background-color: {{VALUE}};',
				],
				'default' => '#081225',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'read_more_h_text_color',
			[
				'label' => __( 'Read More Hover Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_footer a.bg:hover' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'read_more_h_bg_color',
			[
				'label' => __( 'Read More Hover Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_footer a.bg:hover' => 'background-color: {{VALUE}};',
				],
				'default' => '#ad3110',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		$this->add_control(
			'read_more_arr_color',
			[
				'label' => __( 'Read More Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} p.t_footer a.arr' => 'color: {{VALUE}};',
				],
				'default' => '#041230',
				 'condition' => [
					'layout' => 'alpha',
				 ]
			]
		);
		
		$this->add_control(
			'beta_description_color',
			[
				'label' => __( 'Description Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_beta .beta_t_holder p' => 'color: {{VALUE}};',
				],
				'default' => '#777',
				 'condition' => [
					'layout' => 'beta',
				 ]
			]
		);
		
		$this->add_control(
			'beta_description_author_color',
			[
				'label' => __( 'Author Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_beta .beta_t_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .fn_beta .beta_t_holder p a:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#777',
				 'condition' => [
					'layout' => 'beta',
				 ]
			]
		);
		
		$this->add_control(
			'beta_title_color',
			[
				'label' => __( 'Title Regular Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_beta .beta_t_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#1e1e1e',
				 'condition' => [
					'layout' => 'beta',
				 ]
			]
		);
		
		$this->add_control(
			'beta_title_h_color',
			[
				'label' => __( 'Title Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_beta .beta_t_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#1b8ed7',
				 'condition' => [
					'layout' => 'beta',
				 ]
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'container_section',
			[
				'label' => __( 'Container', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'fn_container',
			[
				'label' 	=> __( 'Page Width', 'frenify-core' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'container',
				'options' 	=> [
					''  			=> __( 'Full', 'frenify-core' ),
					'container'  	=> __( 'Contained', 'frenify-core' ),
				],
			]
		);
		
		$this->add_control(
			'fn_container_custom',
			[
				'label' 		=> __( 'Custom Width', 'frenify-core' ),
				'description' 	=> __( 'Default: 1250px', 'frenify-core' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'disabled',
				'options' 		=> [
					'disabled'  	=> __( 'Disabled', 'frenify-core' ),
					'enabled'  		=> __( 'Enabled', 'frenify-core' ),
				],
				'condition' => [
					'fn_container' => 'container',
				]
			]
		);
		
		$this->add_control(
			'fn_container_width',
			[
				'label' 		=> __( 'Max Width', 'frenify-core' ),
				'description' 	=> __( 'Please, mind that container has padding from left and right by 40px.', 'frenify-core' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 		=> [
					'px' => [
						'min' => 0,
						'max' => 3000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1250,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_container.enabled' => 'max-width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'fn_container_custom' => 'enabled',
				]
			]
		);
		
		$this->end_controls_section();

	}




	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 		= $this->get_settings();
		
		
		$time_format	= $settings['time_format'];
		$layout	 		= $settings['layout'];
		$post_offset 	= $settings['post_offset'];
		$post_order 	= $settings['post_order'];
		$post_orderby 	= $settings['post_orderby'];
		$read_more 		= $settings['read_more'];
		$read_more_type	= $settings['read_more_type'];
		
		
		// ****************************** Container ***********************************
		$fnContainer	= $settings['fn_container'];								//*
		$fnContCustom	= $settings['fn_container_custom'];							//*
		if($fnContainer == 'container'){											//*
			$fnC_Start	= '<div class="container fn_container '.$fnContCustom.'">';	//*
			$fnC_End	= '</div>';													//*
		}else{																		//*
			$fnC_Start 	= $fnC_End = '';											//*
		}																			//*
		// ****************************************************************************
		
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}
		$query_args = array(
			'post_type' 			=> 'post',
			'posts_per_page' 		=> 3,
			'post_status' 			=> 'publish',
			'offset' 				=> $post_offset,
			'order' 				=> $post_order,
			'orderby' 				=> $post_orderby,
		);
		
		$industify_post_loop 		= new \WP_Query($query_args);
		
		
		if($time_format === 'month_d_y'){
			$format = 'F j, Y';
		}else if($time_format === 'm_d_y'){
			$format = 'm/d/Y';
		}else if($time_format === 'y_m_d'){
			$format = 'Y/m/d';
		}else if($time_format === 'time'){
			$format = 'G:i';
		}else if($time_format === 'time_pm'){
			$format = 'g:i a';
		}
		
		
		
		$html  = Frel_Helper::frel_open_wrap();
		$html .= '<div class="fn_cs_triple_blog_modern fn_'.$layout.'">'.$fnC_Start.'<div class="inner">';
		$has_img 	= '';
		$posts_part	= '<ul>';
		
		$svg = '<img class="industify_w_fn_svg" src="'.FREL_PLUGIN_URL.'assets/svg/arrow-r.svg" alt="svg" />';
		foreach ( $industify_post_loop->posts as $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 			= $fn_post->ID;
			$post_permalink 	= get_permalink($post_id);
			$post_title			= $fn_post->post_title;
			$post_img			= get_the_post_thumbnail_url($post_id, 'full');
			$category			= Frel_Helper::post_term_list($post_id,'category',false,1);
			
			if($read_more_type === 'arr'){
				$read_more_span = '<span class="text">'.$read_more.'</span><span class="arrow">'.$svg.'</span><span class="arrow_hover">'.$svg.'</span>';
			}else{
				$read_more_span	= $read_more;
			}
			$title 				= '<p class="t_header"><span class="t_author">'.esc_html__('By ', 'frenify-core').'<a href="'.get_author_posts_url(get_the_author_meta('ID')).'">'.get_the_author_meta('user_nicename').'</a></span> — <span class="t_category">'.esc_html__('In ', 'frenify-core').$category.'</span></p><h3><a href="'.$post_permalink.'">'.$post_title.'</a></h3><p class="t_footer"><a class="'.$read_more_type.'" href="'.$post_permalink.'">'.$read_more_span.'</a></p>';
			$post_time			= '<div class="time"><span></span><h3>'.get_the_time('d', $post_id).'</h3><h5>'.get_the_time('M', $post_id).'</h5><h5>'.get_the_time('Y', $post_id).'</h5></div>';
			if($post_img != ''){
				$has_img = 'has_img';
			}else{
				$has_img = 'no_img';
			}
			
			$titleHolder 		= '<div class="title_holder">'.$title.'</div>';
			if($layout == 'beta'){
				$post_time		= '';
				$top 			= '<p class="t_header"><span class="t_author">'.esc_html__('By ', 'frenify-core').'<a href="'.get_author_posts_url(get_the_author_meta('ID')).'">'.get_the_author_meta('user_nicename').'</a></span> / <span>'.get_the_time($format, $post_id).'</span></p>';
				$title 			= $top.'<h3><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
				$titleHolder	= '<div class="beta_t_holder">'.$title.'</div>';
			}
			$img_holder = '<div class="img_holder" data-bg-img="'.$post_img.'">'.$post_time.'<a href="'.$post_permalink.'"></a><img src="'.FREL_PLUGIN_URL.'assets/img/thumb-370-250.jpg" alt="" /></div>';
			$posts_part .= '<li><div class="item '.$has_img.'">'.$img_holder.$titleHolder.'</div></li>';
			wp_reset_postdata();
		}
		$posts_part .= '</ul>';
		$html .= $posts_part;
		$html .= '</div>'.$fnC_End.'</div>';
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
